---
title: <span class="badge builder"></span> Matcher
---
# <span class="badge builder"></span> Matcher

## Constructor

```python
Matcher()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> alerting.Matcher
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> type

```python
def type(type: alerting.MatchType) -> typing.Self
```

### <span class="badge object-method"></span> value

```python
def value(value: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Matcher](./object-Matcher.md)
